****
vspy
****
|build| |pypi| |pyve|

Personal python project template creator.

.. |build| image:: https://github.com/JonSteinn/vspy/workflows/tests/badge.svg
    :alt: GHAction
    :target: https://github.com/JonSteinn/vspy/actions
.. |pypi| image:: https://img.shields.io/pypi/v/vspy
    :alt: PyPI
    :target: https://pypi.org/project/vspy/
.. |pyve| image:: https://img.shields.io/pypi/pyversions/vspy.svg
    :alt: PyV
    :target: https://pypi.python.org/pypi/vspy
